pub(crate) struct AtomProperty<'tcx> {
pub kind: PropertyKind,
pub args: Vec<PropertyArg<'tcx>>,
pub contract_kind: ContractKind,
pub for_each: Option<ContractPlace<'tcx>>,
pub origin: Option<ContractOrigin>,
}Fields
kind: PropertyKindargs: Vec<PropertyArg<'tcx>>contract_kind: ContractKindfor_each: Option<ContractPlace<'tcx>>When set, this property must hold for every element of this
container (e.g. Owning(buckets.iter())). The target place
in args is already stripped of the ForEach projection
and refers to a single element slot.
origin: Option<ContractOrigin>Display metadata when this property was expanded from a compound property.